// Models.swift
//
// Generated by swagger-codegen
// https://github.com/swagger-api/swagger-codegen
//

import Foundation

protocol JSONEncodable {
    func encodeToJSON() -> Any
}

public enum ErrorResponse : Error {
    case HttpError(statusCode: Int, data: Data?, error: Error)
    case DecodeError(response: Data?, decodeError: DecodeError)
}

open class Response<T> {
    open let statusCode: Int
    open let header: [String: String]
    open let body: T?

    public init(statusCode: Int, header: [String: String], body: T?) {
        self.statusCode = statusCode
        self.header = header
        self.body = body
    }

    public convenience init(response: HTTPURLResponse, body: T?) {
        let rawHeader = response.allHeaderFields
        var header = [String:String]()
        for case let (key, value) as (String, String) in rawHeader {
            header[key] = value
        }
        self.init(statusCode: response.statusCode, header: header, body: body)
    }
}

public enum Decoded<ValueType> {
    case success(ValueType)
    case failure(DecodeError)
}

public extension Decoded {
    var value: ValueType? {
        switch self {
        case let .success(value):
            return value
        case .failure:
            return nil
        }
    }
}

public enum DecodeError {
    case typeMismatch(expected: String, actual: String)
    case missingKey(key: String)
    case parseError(message: String)
}

private var once = Int()
class Decoders {
    static fileprivate var decoders = Dictionary<String, ((AnyObject, AnyObject?) -> AnyObject)>()

    static func addDecoder<T>(clazz: T.Type, decoder: @escaping ((AnyObject, AnyObject?) -> Decoded<T>)) {
        let key = "\(T.self)"
        decoders[key] = { decoder($0, $1) as AnyObject }
    }

    static func decode<T>(clazz: T.Type, discriminator: String, source: AnyObject) -> Decoded<T> {
        let key = discriminator
        if let decoder = decoders[key], let value = decoder(source, nil) as? Decoded<T> {
            return value
        } else {
            return .failure(.typeMismatch(expected: String(describing: clazz), actual: String(describing: source)))
        }
    }

    static func decode<T>(clazz: [T].Type, source: AnyObject) -> Decoded<[T]> {
        if let sourceArray = source as? [AnyObject] {
            var values = [T]()
            for sourceValue in sourceArray {
                switch Decoders.decode(clazz: T.self, source: sourceValue, instance: nil) {
                case let .success(value):
                    values.append(value)
                case let .failure(error):
                    return .failure(error)
                }
            }
            return .success(values)
        } else {
            return .failure(.typeMismatch(expected: String(describing: clazz), actual: String(describing: source)))
        }
    }

    static func decode<T>(clazz: T.Type, source: AnyObject) -> Decoded<T> {
        switch Decoders.decode(clazz: T.self, source: source, instance: nil) {
    	    case let .success(value):
                return .success(value)
            case let .failure(error):
                return .failure(error)
        }
    }

    static open func decode<T: RawRepresentable>(clazz: T.Type, source: AnyObject) -> Decoded<T> {
        if let value = source as? T.RawValue {
            if let enumValue = T.init(rawValue: value) {
                return .success(enumValue)
            } else {
                return .failure(.typeMismatch(expected: "A value from the enumeration \(T.self)", actual: "\(value)"))
            }
        } else {
            return .failure(.typeMismatch(expected: "\(T.RawValue.self) matching a case from the enumeration \(T.self)", actual: String(describing: type(of: source))))
        }
    }

    static func decode<T, Key: Hashable>(clazz: [Key:T].Type, source: AnyObject) -> Decoded<[Key:T]> {
        if let sourceDictionary = source as? [Key: AnyObject] {
            var dictionary = [Key:T]()
            for (key, value) in sourceDictionary {
                switch Decoders.decode(clazz: T.self, source: value, instance: nil) {
                case let .success(value):
                    dictionary[key] = value
                case let .failure(error):
                    return .failure(error)
                }
            }
            return .success(dictionary)
        } else {
            return .failure(.typeMismatch(expected: String(describing: clazz), actual: String(describing: source)))
        }
    }

    static func decodeOptional<T: RawRepresentable>(clazz: T.Type, source: AnyObject?) -> Decoded<T?> {
        guard !(source is NSNull), source != nil else { return .success(nil) }
        if let value = source as? T.RawValue {
            if let enumValue = T.init(rawValue: value) {
                return .success(enumValue)
            } else {
                return .failure(.typeMismatch(expected: "A value from the enumeration \(T.self)", actual: "\(value)"))
            }
        } else {
            return .failure(.typeMismatch(expected: "\(T.RawValue.self) matching a case from the enumeration \(T.self)", actual: String(describing: type(of: source))))
        }
    }

    static func decode<T>(clazz: T.Type, source: AnyObject, instance: AnyObject?) -> Decoded<T> {
        initialize()
        if let sourceNumber = source as? NSNumber, let value = sourceNumber.int32Value as? T, T.self is Int32.Type {
            return .success(value)
        }
        if let sourceNumber = source as? NSNumber, let value = sourceNumber.int32Value as? T, T.self is Int64.Type {
     	    return .success(value)
        }
        if let intermediate = source as? String, let value = UUID(uuidString: intermediate) as? T, source is String, T.self is UUID.Type {
            return .success(value)
        }
        if let value = source as? T {
            return .success(value)
        }
        if let intermediate = source as? String, let value = Data(base64Encoded: intermediate) as? T {
            return .success(value)
        }
        let key = "\(T.self)"
        if let decoder = decoders[key], let value = decoder(source, instance) as? Decoded<T> {
           return value
        } else {
            return .failure(.typeMismatch(expected: String(describing: clazz), actual: String(describing: source)))
        }
    }

    //Convert a Decoded so that its value is optional. DO WE STILL NEED THIS?
    static func toOptional<T>(decoded: Decoded<T>) -> Decoded<T?> {
        return .success(decoded.value)
    }

    static func decodeOptional<T>(clazz: T.Type, source: AnyObject?) -> Decoded<T?> {
        if let source = source, !(source is NSNull) {
            switch Decoders.decode(clazz: clazz, source: source, instance: nil) {
            case let .success(value): return .success(value)
            case let .failure(error): return .failure(error)
            }
        } else {
            return .success(nil)
        }
    }

    static func decodeOptional<T>(clazz: [T].Type, source: AnyObject?) -> Decoded<[T]?> where T: RawRepresentable {
        if let source = source as? [AnyObject] {
            var values = [T]()
            for sourceValue in source {
                switch Decoders.decodeOptional(clazz: T.self, source: sourceValue) {
                case let .success(value): if let value = value { values.append(value) }
                case let .failure(error): return .failure(error)
                }
            }
            return .success(values)
        } else {
            return .success(nil)
        }
    }

    static func decodeOptional<T>(clazz: [T].Type, source: AnyObject?) -> Decoded<[T]?> {
        if let source = source as? [AnyObject] {
            var values = [T]()
            for sourceValue in source {
                switch Decoders.decode(clazz: T.self, source: sourceValue, instance: nil) {
                case let .success(value): values.append(value)
                case let .failure(error): return .failure(error)
                }
            }
            return .success(values)
        } else {
            return .success(nil)
        }
    }

    static func decodeOptional<T, Key: Hashable>(clazz: [Key:T].Type, source: AnyObject?) -> Decoded<[Key:T]?> {
        if let sourceDictionary = source as? [Key: AnyObject] {
            var dictionary = [Key:T]()
            for (key, value) in sourceDictionary {
                switch Decoders.decode(clazz: T.self, source: value, instance: nil) {
                case let .success(value): dictionary[key] = value
                case let .failure(error): return .failure(error)
                }
            }
            return .success(dictionary)
        } else {
            return .success(nil)
        }
    }

    static func decodeOptional<T: RawRepresentable, U: AnyObject>(clazz: T, source: AnyObject) -> Decoded<T?> where T.RawValue == U {
        if let value = source as? U {
            if let enumValue = T.init(rawValue: value) {
                return .success(enumValue)
            } else {
                return .failure(.typeMismatch(expected: "A value from the enumeration \(T.self)", actual: "\(value)"))
            }
        } else {
            return .failure(.typeMismatch(expected: "String", actual: String(describing: type(of: source))))
        }
    }


    private static var __once: () = {
        let formatters = [
            "yyyy-MM-dd",
            "yyyy-MM-dd'T'HH:mm:ssZZZZZ",
            "yyyy-MM-dd'T'HH:mm:ss.SSSZZZZZ",
            "yyyy-MM-dd'T'HH:mm:ss'Z'",
            "yyyy-MM-dd'T'HH:mm:ss.SSS",
            "yyyy-MM-dd HH:mm:ss"
        ].map { (format: String) -> DateFormatter in
            let formatter = DateFormatter()
            formatter.locale = Locale(identifier: "en_US_POSIX")
            formatter.dateFormat = format
            return formatter
        }
        // Decoder for Date
        Decoders.addDecoder(clazz: Date.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<Date> in
           if let sourceString = source as? String {
                for formatter in formatters {
                    if let date = formatter.date(from: sourceString) {
                        return .success(date)
                    }
                }
            }
            if let sourceInt = source as? Int {
                // treat as a java date
                return .success(Date(timeIntervalSince1970: Double(sourceInt / 1000) ))
            }
            if source is String || source is Int {
                return .failure(.parseError(message: "Could not decode date"))
            } else {
                return .failure(.typeMismatch(expected: "String or Int", actual: "\(source)"))
            }
        }

        // Decoder for ISOFullDate
        Decoders.addDecoder(clazz: ISOFullDate.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<ISOFullDate> in
            if let string = source as? String,
               let isoDate = ISOFullDate.from(string: string) {
                return .success(isoDate)
            } else {
            	return .failure(.typeMismatch(expected: "ISO date", actual: "\(source)"))
            }
        }

        // Decoder for [BoundingPointsInner]
        Decoders.addDecoder(clazz: [BoundingPointsInner].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[BoundingPointsInner]> in
            return Decoders.decode(clazz: [BoundingPointsInner].self, source: source)
        }

        // Decoder for BoundingPointsInner
        Decoders.addDecoder(clazz: BoundingPointsInner.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<BoundingPointsInner> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? BoundingPointsInner() : instance as! BoundingPointsInner
                switch Decoders.decodeOptional(clazz: OnpointId.self, source: sourceDictionary["onpointId"] as AnyObject?) {
                case let .success(value): _result.onpointId = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Latitude.self, source: sourceDictionary["latitude"] as AnyObject?) {
                case let .success(value): _result.latitude = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Longitude.self, source: sourceDictionary["longitude"] as AnyObject?) {
                case let .success(value): _result.longitude = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Grid.self, source: sourceDictionary["grid"] as AnyObject?) {
                case let .success(value): _result.grid = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Distance.self, source: sourceDictionary["distance"] as AnyObject?) {
                case let .success(value): _result.distance = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "BoundingPointsInner", actual: "\(source)"))
            }
        }
        // Decoder for [CldCvr]
        Decoders.addDecoder(clazz: [CldCvr].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[CldCvr]> in
            return Decoders.decode(clazz: [CldCvr].self, source: source)
        }

        // Decoder for CldCvr
        Decoders.addDecoder(clazz: CldCvr.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<CldCvr> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? CldCvr() : instance as! CldCvr
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "CldCvr", actual: "\(source)"))
            }
        }
        // Decoder for [CldCvrAvg]
        Decoders.addDecoder(clazz: [CldCvrAvg].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[CldCvrAvg]> in
            return Decoders.decode(clazz: [CldCvrAvg].self, source: source)
        }

        // Decoder for CldCvrAvg
        Decoders.addDecoder(clazz: CldCvrAvg.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<CldCvrAvg> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? CldCvrAvg() : instance as! CldCvrAvg
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "CldCvrAvg", actual: "\(source)"))
            }
        }
        // Decoder for [CldCvrMax]
        Decoders.addDecoder(clazz: [CldCvrMax].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[CldCvrMax]> in
            return Decoders.decode(clazz: [CldCvrMax].self, source: source)
        }

        // Decoder for CldCvrMax
        Decoders.addDecoder(clazz: CldCvrMax.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<CldCvrMax> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? CldCvrMax() : instance as! CldCvrMax
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "CldCvrMax", actual: "\(source)"))
            }
        }
        // Decoder for [CldCvrMin]
        Decoders.addDecoder(clazz: [CldCvrMin].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[CldCvrMin]> in
            return Decoders.decode(clazz: [CldCvrMin].self, source: source)
        }

        // Decoder for CldCvrMin
        Decoders.addDecoder(clazz: CldCvrMin.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<CldCvrMin> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? CldCvrMin() : instance as! CldCvrMin
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "CldCvrMin", actual: "\(source)"))
            }
        }
        // Decoder for [CountryCode]
        Decoders.addDecoder(clazz: [CountryCode].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[CountryCode]> in
            return Decoders.decode(clazz: [CountryCode].self, source: source)
        }

        // Decoder for CountryCode
        Decoders.addDecoder(clazz: CountryCode.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<CountryCode> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? CountryCode() : instance as! CountryCode
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "CountryCode", actual: "\(source)"))
            }
        }
        // Decoder for [CountryName]
        Decoders.addDecoder(clazz: [CountryName].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[CountryName]> in
            return Decoders.decode(clazz: [CountryName].self, source: source)
        }

        // Decoder for CountryName
        Decoders.addDecoder(clazz: CountryName.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<CountryName> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? CountryName() : instance as! CountryName
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "CountryName", actual: "\(source)"))
            }
        }
        // Decoder for [Date]
        Decoders.addDecoder(clazz: [Date].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[Date]> in
            return Decoders.decode(clazz: [Date].self, source: source)
        }

        // Decoder for Date
        Decoders.addDecoder(clazz: Date.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<Date> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? Date() : instance as! Date
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "Date", actual: "\(source)"))
            }
        }
        // Decoder for [DateEnd]
        Decoders.addDecoder(clazz: [DateEnd].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[DateEnd]> in
            return Decoders.decode(clazz: [DateEnd].self, source: source)
        }

        // Decoder for DateEnd
        Decoders.addDecoder(clazz: DateEnd.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<DateEnd> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? DateEnd() : instance as! DateEnd
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "DateEnd", actual: "\(source)"))
            }
        }
        // Decoder for [DateRangeObj]
        Decoders.addDecoder(clazz: [DateRangeObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[DateRangeObj]> in
            return Decoders.decode(clazz: [DateRangeObj].self, source: source)
        }

        // Decoder for DateRangeObj
        Decoders.addDecoder(clazz: DateRangeObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<DateRangeObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? DateRangeObj() : instance as! DateRangeObj
                switch Decoders.decodeOptional(clazz: DateStart.self, source: sourceDictionary["dateStart"] as AnyObject?) {
                case let .success(value): _result.dateStart = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: DateEnd.self, source: sourceDictionary["dateEnd"] as AnyObject?) {
                case let .success(value): _result.dateEnd = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "DateRangeObj", actual: "\(source)"))
            }
        }
        // Decoder for [DateStart]
        Decoders.addDecoder(clazz: [DateStart].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[DateStart]> in
            return Decoders.decode(clazz: [DateStart].self, source: source)
        }

        // Decoder for DateStart
        Decoders.addDecoder(clazz: DateStart.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<DateStart> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? DateStart() : instance as! DateStart
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "DateStart", actual: "\(source)"))
            }
        }
        // Decoder for [DewPt]
        Decoders.addDecoder(clazz: [DewPt].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[DewPt]> in
            return Decoders.decode(clazz: [DewPt].self, source: source)
        }

        // Decoder for DewPt
        Decoders.addDecoder(clazz: DewPt.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<DewPt> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? DewPt() : instance as! DewPt
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "DewPt", actual: "\(source)"))
            }
        }
        // Decoder for [DewPtAvg]
        Decoders.addDecoder(clazz: [DewPtAvg].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[DewPtAvg]> in
            return Decoders.decode(clazz: [DewPtAvg].self, source: source)
        }

        // Decoder for DewPtAvg
        Decoders.addDecoder(clazz: DewPtAvg.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<DewPtAvg> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? DewPtAvg() : instance as! DewPtAvg
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "DewPtAvg", actual: "\(source)"))
            }
        }
        // Decoder for [DewPtMax]
        Decoders.addDecoder(clazz: [DewPtMax].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[DewPtMax]> in
            return Decoders.decode(clazz: [DewPtMax].self, source: source)
        }

        // Decoder for DewPtMax
        Decoders.addDecoder(clazz: DewPtMax.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<DewPtMax> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? DewPtMax() : instance as! DewPtMax
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "DewPtMax", actual: "\(source)"))
            }
        }
        // Decoder for [DewPtMin]
        Decoders.addDecoder(clazz: [DewPtMin].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[DewPtMin]> in
            return Decoders.decode(clazz: [DewPtMin].self, source: source)
        }

        // Decoder for DewPtMin
        Decoders.addDecoder(clazz: DewPtMin.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<DewPtMin> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? DewPtMin() : instance as! DewPtMin
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "DewPtMin", actual: "\(source)"))
            }
        }
        // Decoder for [Distance]
        Decoders.addDecoder(clazz: [Distance].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[Distance]> in
            return Decoders.decode(clazz: [Distance].self, source: source)
        }

        // Decoder for Distance
        Decoders.addDecoder(clazz: Distance.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<Distance> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? Distance() : instance as! Distance
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "Distance", actual: "\(source)"))
            }
        }
        // Decoder for [DistancePop]
        Decoders.addDecoder(clazz: [DistancePop].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[DistancePop]> in
            return Decoders.decode(clazz: [DistancePop].self, source: source)
        }

        // Decoder for DistancePop
        Decoders.addDecoder(clazz: DistancePop.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<DistancePop> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? DistancePop() : instance as! DistancePop
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "DistancePop", actual: "\(source)"))
            }
        }
        // Decoder for [DmaId]
        Decoders.addDecoder(clazz: [DmaId].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[DmaId]> in
            return Decoders.decode(clazz: [DmaId].self, source: source)
        }

        // Decoder for DmaId
        Decoders.addDecoder(clazz: DmaId.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<DmaId> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? DmaId() : instance as! DmaId
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "DmaId", actual: "\(source)"))
            }
        }
        // Decoder for [DmaName]
        Decoders.addDecoder(clazz: [DmaName].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[DmaName]> in
            return Decoders.decode(clazz: [DmaName].self, source: source)
        }

        // Decoder for DmaName
        Decoders.addDecoder(clazz: DmaName.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<DmaName> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? DmaName() : instance as! DmaName
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "DmaName", actual: "\(source)"))
            }
        }
        // Decoder for [DmaObj]
        Decoders.addDecoder(clazz: [DmaObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[DmaObj]> in
            return Decoders.decode(clazz: [DmaObj].self, source: source)
        }

        // Decoder for DmaObj
        Decoders.addDecoder(clazz: DmaObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<DmaObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? DmaObj() : instance as! DmaObj
                switch Decoders.decodeOptional(clazz: DmaId.self, source: sourceDictionary["dmaId"] as AnyObject?) {
                case let .success(value): _result.dmaId = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: DmaName.self, source: sourceDictionary["dmaName"] as AnyObject?) {
                case let .success(value): _result.dmaName = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Timezone.self, source: sourceDictionary["timezone"] as AnyObject?) {
                case let .success(value): _result.timezone = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Population.self, source: sourceDictionary["population"] as AnyObject?) {
                case let .success(value): _result.population = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: CountryCode.self, source: sourceDictionary["countryCode"] as AnyObject?) {
                case let .success(value): _result.countryCode = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: CountryName.self, source: sourceDictionary["countryName"] as AnyObject?) {
                case let .success(value): _result.countryName = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: SamplePoints.self, source: sourceDictionary["samplePoints"] as AnyObject?) {
                case let .success(value): _result.samplePoints = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Grid.self, source: sourceDictionary["grid"] as AnyObject?) {
                case let .success(value): _result.grid = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "DmaObj", actual: "\(source)"))
            }
        }
        // Decoder for [ErrorObj]
        Decoders.addDecoder(clazz: [ErrorObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[ErrorObj]> in
            return Decoders.decode(clazz: [ErrorObj].self, source: source)
        }

        // Decoder for ErrorObj
        Decoders.addDecoder(clazz: ErrorObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<ErrorObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? ErrorObj() : instance as! ErrorObj
                switch Decoders.decodeOptional(clazz: Int32.self, source: sourceDictionary["errorCode"] as AnyObject?) {
                case let .success(value): _result.errorCode = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: String.self, source: sourceDictionary["errorMessage"] as AnyObject?) {
                case let .success(value): _result.errorMessage = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "ErrorObj", actual: "\(source)"))
            }
        }
        // Decoder for [FeelsLike]
        Decoders.addDecoder(clazz: [FeelsLike].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[FeelsLike]> in
            return Decoders.decode(clazz: [FeelsLike].self, source: source)
        }

        // Decoder for FeelsLike
        Decoders.addDecoder(clazz: FeelsLike.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<FeelsLike> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? FeelsLike() : instance as! FeelsLike
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "FeelsLike", actual: "\(source)"))
            }
        }
        // Decoder for [FeelsLikeAvg]
        Decoders.addDecoder(clazz: [FeelsLikeAvg].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[FeelsLikeAvg]> in
            return Decoders.decode(clazz: [FeelsLikeAvg].self, source: source)
        }

        // Decoder for FeelsLikeAvg
        Decoders.addDecoder(clazz: FeelsLikeAvg.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<FeelsLikeAvg> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? FeelsLikeAvg() : instance as! FeelsLikeAvg
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "FeelsLikeAvg", actual: "\(source)"))
            }
        }
        // Decoder for [FeelsLikeMax]
        Decoders.addDecoder(clazz: [FeelsLikeMax].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[FeelsLikeMax]> in
            return Decoders.decode(clazz: [FeelsLikeMax].self, source: source)
        }

        // Decoder for FeelsLikeMax
        Decoders.addDecoder(clazz: FeelsLikeMax.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<FeelsLikeMax> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? FeelsLikeMax() : instance as! FeelsLikeMax
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "FeelsLikeMax", actual: "\(source)"))
            }
        }
        // Decoder for [FeelsLikeMin]
        Decoders.addDecoder(clazz: [FeelsLikeMin].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[FeelsLikeMin]> in
            return Decoders.decode(clazz: [FeelsLikeMin].self, source: source)
        }

        // Decoder for FeelsLikeMin
        Decoders.addDecoder(clazz: FeelsLikeMin.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<FeelsLikeMin> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? FeelsLikeMin() : instance as! FeelsLikeMin
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "FeelsLikeMin", actual: "\(source)"))
            }
        }
        // Decoder for [FieldListDayObj]
        Decoders.addDecoder(clazz: [FieldListDayObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[FieldListDayObj]> in
            return Decoders.decode(clazz: [FieldListDayObj].self, source: source)
        }

        // Decoder for FieldListDayObj
        Decoders.addDecoder(clazz: FieldListDayObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<FieldListDayObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? FieldListDayObj() : instance as! FieldListDayObj
                switch Decoders.decodeOptional(clazz: Fields.self, source: sourceDictionary["fields"] as AnyObject?) {
                case let .success(value): _result.fields = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "FieldListDayObj", actual: "\(source)"))
            }
        }
        // Decoder for [FieldListHourObj]
        Decoders.addDecoder(clazz: [FieldListHourObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[FieldListHourObj]> in
            return Decoders.decode(clazz: [FieldListHourObj].self, source: source)
        }

        // Decoder for FieldListHourObj
        Decoders.addDecoder(clazz: FieldListHourObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<FieldListHourObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? FieldListHourObj() : instance as! FieldListHourObj
                switch Decoders.decodeOptional(clazz: Fields.self, source: sourceDictionary["fields"] as AnyObject?) {
                case let .success(value): _result.fields = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "FieldListHourObj", actual: "\(source)"))
            }
        }
        // Decoder for [Fields]
        Decoders.addDecoder(clazz: [Fields].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[Fields]> in
            return Decoders.decode(clazz: [Fields].self, source: source)
        }

        // Decoder for Fields
        Decoders.addDecoder(clazz: Fields.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<Fields> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
            var propsDictionary = sourceDictionary
            let keys : [AnyHashable] = []
                let _result = instance == nil ? Fields() : instance as! Fields
                if decoders["\(String.self)"] != nil {
                  _ = Decoders.decode(clazz: String.self, source: source, instance: _result)
                }

                for key in keys {
                    propsDictionary.removeValue(forKey: key)
                }

                for key in propsDictionary.keys {
                    switch  Decoders.decodeOptional(clazz: String.self, source: propsDictionary[key] as AnyObject?) {

                    case let .success(value): _result[key] = value
                    default: continue

                    }
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "Fields", actual: "\(source)"))
            }
        }
        // Decoder for [ForecastDayObj]
        Decoders.addDecoder(clazz: [ForecastDayObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[ForecastDayObj]> in
            return Decoders.decode(clazz: [ForecastDayObj].self, source: source)
        }

        // Decoder for ForecastDayObj
        Decoders.addDecoder(clazz: ForecastDayObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<ForecastDayObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? ForecastDayObj() : instance as! ForecastDayObj
                switch Decoders.decodeOptional(clazz: ISOFullDate.self, source: sourceDictionary["date"] as AnyObject?) {
                case let .success(value): _result.date = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: TimestampInit.self, source: sourceDictionary["timestampInit"] as AnyObject?) {
                case let .success(value): _result.timestampInit = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: CldCvrMin.self, source: sourceDictionary["cldCvrMin"] as AnyObject?) {
                case let .success(value): _result.cldCvrMin = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: CldCvrAvg.self, source: sourceDictionary["cldCvrAvg"] as AnyObject?) {
                case let .success(value): _result.cldCvrAvg = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: CldCvrMax.self, source: sourceDictionary["cldCvrMax"] as AnyObject?) {
                case let .success(value): _result.cldCvrMax = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: DewPtMin.self, source: sourceDictionary["dewPtMin"] as AnyObject?) {
                case let .success(value): _result.dewPtMin = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: DewPtAvg.self, source: sourceDictionary["dewPtAvg"] as AnyObject?) {
                case let .success(value): _result.dewPtAvg = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: DewPtMax.self, source: sourceDictionary["dewPtMax"] as AnyObject?) {
                case let .success(value): _result.dewPtMax = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: FeelsLikeMin.self, source: sourceDictionary["feelsLikeMin"] as AnyObject?) {
                case let .success(value): _result.feelsLikeMin = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: FeelsLikeAvg.self, source: sourceDictionary["feelsLikeAvg"] as AnyObject?) {
                case let .success(value): _result.feelsLikeAvg = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: FeelsLikeMax.self, source: sourceDictionary["feelsLikeMax"] as AnyObject?) {
                case let .success(value): _result.feelsLikeMax = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: HeatIndexMin.self, source: sourceDictionary["heatIndexMin"] as AnyObject?) {
                case let .success(value): _result.heatIndexMin = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: HeatIndexAvg.self, source: sourceDictionary["heatIndexAvg"] as AnyObject?) {
                case let .success(value): _result.heatIndexAvg = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: HeatIndexMax.self, source: sourceDictionary["heatIndexMax"] as AnyObject?) {
                case let .success(value): _result.heatIndexMax = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: MslPresMin.self, source: sourceDictionary["mslPresMin"] as AnyObject?) {
                case let .success(value): _result.mslPresMin = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: MslPresAvg.self, source: sourceDictionary["mslPresAvg"] as AnyObject?) {
                case let .success(value): _result.mslPresAvg = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: MslPresMax.self, source: sourceDictionary["mslPresMax"] as AnyObject?) {
                case let .success(value): _result.mslPresMax = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Precip.self, source: sourceDictionary["precip"] as AnyObject?) {
                case let .success(value): _result.precip = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: PrecipProb.self, source: sourceDictionary["precipProb"] as AnyObject?) {
                case let .success(value): _result.precipProb = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: RadSolarMin.self, source: sourceDictionary["radSolarMin"] as AnyObject?) {
                case let .success(value): _result.radSolarMin = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: RadSolarAvg.self, source: sourceDictionary["radSolarAvg"] as AnyObject?) {
                case let .success(value): _result.radSolarAvg = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: RadSolarMax.self, source: sourceDictionary["radSolarMax"] as AnyObject?) {
                case let .success(value): _result.radSolarMax = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: RadSolarTot.self, source: sourceDictionary["radSolarTot"] as AnyObject?) {
                case let .success(value): _result.radSolarTot = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: RelHumMin.self, source: sourceDictionary["relHumMin"] as AnyObject?) {
                case let .success(value): _result.relHumMin = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: RelHumAvg.self, source: sourceDictionary["relHumAvg"] as AnyObject?) {
                case let .success(value): _result.relHumAvg = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: RelHumMax.self, source: sourceDictionary["relHumMax"] as AnyObject?) {
                case let .success(value): _result.relHumMax = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: SfcPresMin.self, source: sourceDictionary["sfcPresMin"] as AnyObject?) {
                case let .success(value): _result.sfcPresMin = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: SfcPresAvg.self, source: sourceDictionary["sfcPresAvg"] as AnyObject?) {
                case let .success(value): _result.sfcPresAvg = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: SfcPresMax.self, source: sourceDictionary["sfcPresMax"] as AnyObject?) {
                case let .success(value): _result.sfcPresMax = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Snowfall.self, source: sourceDictionary["snowfall"] as AnyObject?) {
                case let .success(value): _result.snowfall = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: SnowfallProb.self, source: sourceDictionary["snowfallProb"] as AnyObject?) {
                case let .success(value): _result.snowfallProb = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: SpcHumMin.self, source: sourceDictionary["spcHumMin"] as AnyObject?) {
                case let .success(value): _result.spcHumMin = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: SpcHumAvg.self, source: sourceDictionary["spcHumAvg"] as AnyObject?) {
                case let .success(value): _result.spcHumAvg = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: SpcHumMax.self, source: sourceDictionary["spcHumMax"] as AnyObject?) {
                case let .success(value): _result.spcHumMax = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: TempMin.self, source: sourceDictionary["tempMin"] as AnyObject?) {
                case let .success(value): _result.tempMin = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: TempAvg.self, source: sourceDictionary["tempAvg"] as AnyObject?) {
                case let .success(value): _result.tempAvg = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: TempMax.self, source: sourceDictionary["tempMax"] as AnyObject?) {
                case let .success(value): _result.tempMax = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WetBulbMin.self, source: sourceDictionary["wetBulbMin"] as AnyObject?) {
                case let .success(value): _result.wetBulbMin = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WetBulbAvg.self, source: sourceDictionary["wetBulbAvg"] as AnyObject?) {
                case let .success(value): _result.wetBulbAvg = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WetBulbMax.self, source: sourceDictionary["wetBulbMax"] as AnyObject?) {
                case let .success(value): _result.wetBulbMax = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindChillMin.self, source: sourceDictionary["windChillMin"] as AnyObject?) {
                case let .success(value): _result.windChillMin = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindChillAvg.self, source: sourceDictionary["windChillAvg"] as AnyObject?) {
                case let .success(value): _result.windChillAvg = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindChillMax.self, source: sourceDictionary["windChillMax"] as AnyObject?) {
                case let .success(value): _result.windChillMax = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindDirAvg.self, source: sourceDictionary["windDirAvg"] as AnyObject?) {
                case let .success(value): _result.windDirAvg = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindDir80mAvg.self, source: sourceDictionary["windDir80mAvg"] as AnyObject?) {
                case let .success(value): _result.windDir80mAvg = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindDir100mAvg.self, source: sourceDictionary["windDir100mAvg"] as AnyObject?) {
                case let .success(value): _result.windDir100mAvg = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindSpdMin.self, source: sourceDictionary["windSpdMin"] as AnyObject?) {
                case let .success(value): _result.windSpdMin = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindSpdAvg.self, source: sourceDictionary["windSpdAvg"] as AnyObject?) {
                case let .success(value): _result.windSpdAvg = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindSpdMax.self, source: sourceDictionary["windSpdMax"] as AnyObject?) {
                case let .success(value): _result.windSpdMax = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindSpd80mMin.self, source: sourceDictionary["windSpd80mMin"] as AnyObject?) {
                case let .success(value): _result.windSpd80mMin = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindSpd80mAvg.self, source: sourceDictionary["windSpd80mAvg"] as AnyObject?) {
                case let .success(value): _result.windSpd80mAvg = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindSpd80mMax.self, source: sourceDictionary["windSpd80mMax"] as AnyObject?) {
                case let .success(value): _result.windSpd80mMax = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindSpd100mMin.self, source: sourceDictionary["windSpd100mMin"] as AnyObject?) {
                case let .success(value): _result.windSpd100mMin = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindSpd100mAvg.self, source: sourceDictionary["windSpd100mAvg"] as AnyObject?) {
                case let .success(value): _result.windSpd100mAvg = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindSpd100mMax.self, source: sourceDictionary["windSpd100mMax"] as AnyObject?) {
                case let .success(value): _result.windSpd100mMax = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "ForecastDayObj", actual: "\(source)"))
            }
        }
        // Decoder for [ForecastDmaDayObj]
        Decoders.addDecoder(clazz: [ForecastDmaDayObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[ForecastDmaDayObj]> in
            return Decoders.decode(clazz: [ForecastDmaDayObj].self, source: source)
        }

        // Decoder for ForecastDmaDayObj
        Decoders.addDecoder(clazz: ForecastDmaDayObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<ForecastDmaDayObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? ForecastDmaDayObj() : instance as! ForecastDmaDayObj
                switch Decoders.decodeOptional(clazz: DmaObj.self, source: sourceDictionary["location"] as AnyObject?) {
                case let .success(value): _result.location = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: DateRangeObj.self, source: sourceDictionary["dateRange"] as AnyObject?) {
                case let .success(value): _result.dateRange = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: FieldListDayObj.self, source: sourceDictionary["fieldList"] as AnyObject?) {
                case let .success(value): _result.fieldList = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: ForecastDayArr.self, source: sourceDictionary["forecast"] as AnyObject?) {
                case let .success(value): _result.forecast = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "ForecastDmaDayObj", actual: "\(source)"))
            }
        }
        // Decoder for [ForecastDmaHourObj]
        Decoders.addDecoder(clazz: [ForecastDmaHourObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[ForecastDmaHourObj]> in
            return Decoders.decode(clazz: [ForecastDmaHourObj].self, source: source)
        }

        // Decoder for ForecastDmaHourObj
        Decoders.addDecoder(clazz: ForecastDmaHourObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<ForecastDmaHourObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? ForecastDmaHourObj() : instance as! ForecastDmaHourObj
                switch Decoders.decodeOptional(clazz: DmaObj.self, source: sourceDictionary["location"] as AnyObject?) {
                case let .success(value): _result.location = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: TimestampRangeObj.self, source: sourceDictionary["timestampRange"] as AnyObject?) {
                case let .success(value): _result.timestampRange = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: FieldListHourObj.self, source: sourceDictionary["fieldList"] as AnyObject?) {
                case let .success(value): _result.fieldList = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: ForecastHourArr.self, source: sourceDictionary["forecast"] as AnyObject?) {
                case let .success(value): _result.forecast = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "ForecastDmaHourObj", actual: "\(source)"))
            }
        }
        // Decoder for [ForecastHourObj]
        Decoders.addDecoder(clazz: [ForecastHourObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[ForecastHourObj]> in
            return Decoders.decode(clazz: [ForecastHourObj].self, source: source)
        }

        // Decoder for ForecastHourObj
        Decoders.addDecoder(clazz: ForecastHourObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<ForecastHourObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? ForecastHourObj() : instance as! ForecastHourObj
                switch Decoders.decodeOptional(clazz: Timestamp.self, source: sourceDictionary["timestamp"] as AnyObject?) {
                case let .success(value): _result.timestamp = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: TimestampInit.self, source: sourceDictionary["timestampInit"] as AnyObject?) {
                case let .success(value): _result.timestampInit = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: CldCvr.self, source: sourceDictionary["cldCvr"] as AnyObject?) {
                case let .success(value): _result.cldCvr = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: DewPt.self, source: sourceDictionary["dewPt"] as AnyObject?) {
                case let .success(value): _result.dewPt = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: FeelsLike.self, source: sourceDictionary["feelsLike"] as AnyObject?) {
                case let .success(value): _result.feelsLike = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: HeatIndex.self, source: sourceDictionary["heatIndex"] as AnyObject?) {
                case let .success(value): _result.heatIndex = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: MslPres.self, source: sourceDictionary["mslPres"] as AnyObject?) {
                case let .success(value): _result.mslPres = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Precip.self, source: sourceDictionary["precip"] as AnyObject?) {
                case let .success(value): _result.precip = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: PrecipProb.self, source: sourceDictionary["precipProb"] as AnyObject?) {
                case let .success(value): _result.precipProb = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: RadSolar.self, source: sourceDictionary["radSolar"] as AnyObject?) {
                case let .success(value): _result.radSolar = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: RelHum.self, source: sourceDictionary["relHum"] as AnyObject?) {
                case let .success(value): _result.relHum = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: SfcPres.self, source: sourceDictionary["sfcPres"] as AnyObject?) {
                case let .success(value): _result.sfcPres = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Snowfall.self, source: sourceDictionary["snowfall"] as AnyObject?) {
                case let .success(value): _result.snowfall = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: SnowfallProb.self, source: sourceDictionary["snowfallProb"] as AnyObject?) {
                case let .success(value): _result.snowfallProb = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: SpcHum.self, source: sourceDictionary["spcHum"] as AnyObject?) {
                case let .success(value): _result.spcHum = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Temp.self, source: sourceDictionary["temp"] as AnyObject?) {
                case let .success(value): _result.temp = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WetBulb.self, source: sourceDictionary["wetBulb"] as AnyObject?) {
                case let .success(value): _result.wetBulb = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindChill.self, source: sourceDictionary["windChill"] as AnyObject?) {
                case let .success(value): _result.windChill = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindDir.self, source: sourceDictionary["windDir"] as AnyObject?) {
                case let .success(value): _result.windDir = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindDir80m.self, source: sourceDictionary["windDir80m"] as AnyObject?) {
                case let .success(value): _result.windDir80m = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindDir100m.self, source: sourceDictionary["windDir100m"] as AnyObject?) {
                case let .success(value): _result.windDir100m = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindSpd.self, source: sourceDictionary["windSpd"] as AnyObject?) {
                case let .success(value): _result.windSpd = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindSpd80m.self, source: sourceDictionary["windSpd80m"] as AnyObject?) {
                case let .success(value): _result.windSpd80m = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: WindSpd100m.self, source: sourceDictionary["windSpd100m"] as AnyObject?) {
                case let .success(value): _result.windSpd100m = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "ForecastHourObj", actual: "\(source)"))
            }
        }
        // Decoder for [ForecastOnpointDayObj]
        Decoders.addDecoder(clazz: [ForecastOnpointDayObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[ForecastOnpointDayObj]> in
            return Decoders.decode(clazz: [ForecastOnpointDayObj].self, source: source)
        }

        // Decoder for ForecastOnpointDayObj
        Decoders.addDecoder(clazz: ForecastOnpointDayObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<ForecastOnpointDayObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? ForecastOnpointDayObj() : instance as! ForecastOnpointDayObj
                switch Decoders.decodeOptional(clazz: OnpointObj.self, source: sourceDictionary["location"] as AnyObject?) {
                case let .success(value): _result.location = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: DateRangeObj.self, source: sourceDictionary["dateRange"] as AnyObject?) {
                case let .success(value): _result.dateRange = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: FieldListDayObj.self, source: sourceDictionary["fieldList"] as AnyObject?) {
                case let .success(value): _result.fieldList = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: ForecastDayArr.self, source: sourceDictionary["forecast"] as AnyObject?) {
                case let .success(value): _result.forecast = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "ForecastOnpointDayObj", actual: "\(source)"))
            }
        }
        // Decoder for [ForecastOnpointHourObj]
        Decoders.addDecoder(clazz: [ForecastOnpointHourObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[ForecastOnpointHourObj]> in
            return Decoders.decode(clazz: [ForecastOnpointHourObj].self, source: source)
        }

        // Decoder for ForecastOnpointHourObj
        Decoders.addDecoder(clazz: ForecastOnpointHourObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<ForecastOnpointHourObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? ForecastOnpointHourObj() : instance as! ForecastOnpointHourObj
                switch Decoders.decodeOptional(clazz: OnpointObj.self, source: sourceDictionary["location"] as AnyObject?) {
                case let .success(value): _result.location = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: TimestampRangeObj.self, source: sourceDictionary["timestampRange"] as AnyObject?) {
                case let .success(value): _result.timestampRange = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: FieldListHourObj.self, source: sourceDictionary["fieldList"] as AnyObject?) {
                case let .success(value): _result.fieldList = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: ForecastHourArr.self, source: sourceDictionary["forecast"] as AnyObject?) {
                case let .success(value): _result.forecast = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "ForecastOnpointHourObj", actual: "\(source)"))
            }
        }
        // Decoder for [ForecastPointDayObj]
        Decoders.addDecoder(clazz: [ForecastPointDayObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[ForecastPointDayObj]> in
            return Decoders.decode(clazz: [ForecastPointDayObj].self, source: source)
        }

        // Decoder for ForecastPointDayObj
        Decoders.addDecoder(clazz: ForecastPointDayObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<ForecastPointDayObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? ForecastPointDayObj() : instance as! ForecastPointDayObj
                switch Decoders.decodeOptional(clazz: PointObj.self, source: sourceDictionary["location"] as AnyObject?) {
                case let .success(value): _result.location = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: DateRangeObj.self, source: sourceDictionary["dateRange"] as AnyObject?) {
                case let .success(value): _result.dateRange = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: FieldListDayObj.self, source: sourceDictionary["fieldList"] as AnyObject?) {
                case let .success(value): _result.fieldList = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: ForecastDayArr.self, source: sourceDictionary["forecast"] as AnyObject?) {
                case let .success(value): _result.forecast = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "ForecastPointDayObj", actual: "\(source)"))
            }
        }
        // Decoder for [ForecastPointHourObj]
        Decoders.addDecoder(clazz: [ForecastPointHourObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[ForecastPointHourObj]> in
            return Decoders.decode(clazz: [ForecastPointHourObj].self, source: source)
        }

        // Decoder for ForecastPointHourObj
        Decoders.addDecoder(clazz: ForecastPointHourObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<ForecastPointHourObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? ForecastPointHourObj() : instance as! ForecastPointHourObj
                switch Decoders.decodeOptional(clazz: PointObj.self, source: sourceDictionary["location"] as AnyObject?) {
                case let .success(value): _result.location = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: TimestampRangeObj.self, source: sourceDictionary["timestampRange"] as AnyObject?) {
                case let .success(value): _result.timestampRange = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: FieldListHourObj.self, source: sourceDictionary["fieldList"] as AnyObject?) {
                case let .success(value): _result.fieldList = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: ForecastHourArr.self, source: sourceDictionary["forecast"] as AnyObject?) {
                case let .success(value): _result.forecast = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "ForecastPointHourObj", actual: "\(source)"))
            }
        }
        // Decoder for [ForecastPostcodeDayObj]
        Decoders.addDecoder(clazz: [ForecastPostcodeDayObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[ForecastPostcodeDayObj]> in
            return Decoders.decode(clazz: [ForecastPostcodeDayObj].self, source: source)
        }

        // Decoder for ForecastPostcodeDayObj
        Decoders.addDecoder(clazz: ForecastPostcodeDayObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<ForecastPostcodeDayObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? ForecastPostcodeDayObj() : instance as! ForecastPostcodeDayObj
                switch Decoders.decodeOptional(clazz: PostcodeObj.self, source: sourceDictionary["location"] as AnyObject?) {
                case let .success(value): _result.location = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: DateRangeObj.self, source: sourceDictionary["dateRange"] as AnyObject?) {
                case let .success(value): _result.dateRange = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: FieldListDayObj.self, source: sourceDictionary["fieldList"] as AnyObject?) {
                case let .success(value): _result.fieldList = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: ForecastDayArr.self, source: sourceDictionary["forecast"] as AnyObject?) {
                case let .success(value): _result.forecast = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "ForecastPostcodeDayObj", actual: "\(source)"))
            }
        }
        // Decoder for [ForecastPostcodeHourObj]
        Decoders.addDecoder(clazz: [ForecastPostcodeHourObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[ForecastPostcodeHourObj]> in
            return Decoders.decode(clazz: [ForecastPostcodeHourObj].self, source: source)
        }

        // Decoder for ForecastPostcodeHourObj
        Decoders.addDecoder(clazz: ForecastPostcodeHourObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<ForecastPostcodeHourObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? ForecastPostcodeHourObj() : instance as! ForecastPostcodeHourObj
                switch Decoders.decodeOptional(clazz: PostcodeObj.self, source: sourceDictionary["location"] as AnyObject?) {
                case let .success(value): _result.location = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: TimestampRangeObj.self, source: sourceDictionary["timestampRange"] as AnyObject?) {
                case let .success(value): _result.timestampRange = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: FieldListHourObj.self, source: sourceDictionary["fieldList"] as AnyObject?) {
                case let .success(value): _result.fieldList = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: ForecastHourArr.self, source: sourceDictionary["forecast"] as AnyObject?) {
                case let .success(value): _result.forecast = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "ForecastPostcodeHourObj", actual: "\(source)"))
            }
        }
        // Decoder for [Grid]
        Decoders.addDecoder(clazz: [Grid].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[Grid]> in
            return Decoders.decode(clazz: [Grid].self, source: source)
        }

        // Decoder for Grid
        Decoders.addDecoder(clazz: Grid.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<Grid> in
            //TODO: I don't think we need this anymore
            return Decoders.decode(clazz: Grid.self, source: source, instance: instance)
        }
        // Decoder for [HeatIndex]
        Decoders.addDecoder(clazz: [HeatIndex].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[HeatIndex]> in
            return Decoders.decode(clazz: [HeatIndex].self, source: source)
        }

        // Decoder for HeatIndex
        Decoders.addDecoder(clazz: HeatIndex.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<HeatIndex> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? HeatIndex() : instance as! HeatIndex
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "HeatIndex", actual: "\(source)"))
            }
        }
        // Decoder for [HeatIndexAvg]
        Decoders.addDecoder(clazz: [HeatIndexAvg].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[HeatIndexAvg]> in
            return Decoders.decode(clazz: [HeatIndexAvg].self, source: source)
        }

        // Decoder for HeatIndexAvg
        Decoders.addDecoder(clazz: HeatIndexAvg.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<HeatIndexAvg> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? HeatIndexAvg() : instance as! HeatIndexAvg
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "HeatIndexAvg", actual: "\(source)"))
            }
        }
        // Decoder for [HeatIndexMax]
        Decoders.addDecoder(clazz: [HeatIndexMax].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[HeatIndexMax]> in
            return Decoders.decode(clazz: [HeatIndexMax].self, source: source)
        }

        // Decoder for HeatIndexMax
        Decoders.addDecoder(clazz: HeatIndexMax.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<HeatIndexMax> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? HeatIndexMax() : instance as! HeatIndexMax
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "HeatIndexMax", actual: "\(source)"))
            }
        }
        // Decoder for [HeatIndexMin]
        Decoders.addDecoder(clazz: [HeatIndexMin].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[HeatIndexMin]> in
            return Decoders.decode(clazz: [HeatIndexMin].self, source: source)
        }

        // Decoder for HeatIndexMin
        Decoders.addDecoder(clazz: HeatIndexMin.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<HeatIndexMin> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? HeatIndexMin() : instance as! HeatIndexMin
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "HeatIndexMin", actual: "\(source)"))
            }
        }
        // Decoder for [Latitude]
        Decoders.addDecoder(clazz: [Latitude].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[Latitude]> in
            return Decoders.decode(clazz: [Latitude].self, source: source)
        }

        // Decoder for Latitude
        Decoders.addDecoder(clazz: Latitude.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<Latitude> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? Latitude() : instance as! Latitude
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "Latitude", actual: "\(source)"))
            }
        }
        // Decoder for [Longitude]
        Decoders.addDecoder(clazz: [Longitude].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[Longitude]> in
            return Decoders.decode(clazz: [Longitude].self, source: source)
        }

        // Decoder for Longitude
        Decoders.addDecoder(clazz: Longitude.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<Longitude> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? Longitude() : instance as! Longitude
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "Longitude", actual: "\(source)"))
            }
        }
        // Decoder for [MslPres]
        Decoders.addDecoder(clazz: [MslPres].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[MslPres]> in
            return Decoders.decode(clazz: [MslPres].self, source: source)
        }

        // Decoder for MslPres
        Decoders.addDecoder(clazz: MslPres.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<MslPres> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? MslPres() : instance as! MslPres
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "MslPres", actual: "\(source)"))
            }
        }
        // Decoder for [MslPresAvg]
        Decoders.addDecoder(clazz: [MslPresAvg].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[MslPresAvg]> in
            return Decoders.decode(clazz: [MslPresAvg].self, source: source)
        }

        // Decoder for MslPresAvg
        Decoders.addDecoder(clazz: MslPresAvg.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<MslPresAvg> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? MslPresAvg() : instance as! MslPresAvg
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "MslPresAvg", actual: "\(source)"))
            }
        }
        // Decoder for [MslPresMax]
        Decoders.addDecoder(clazz: [MslPresMax].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[MslPresMax]> in
            return Decoders.decode(clazz: [MslPresMax].self, source: source)
        }

        // Decoder for MslPresMax
        Decoders.addDecoder(clazz: MslPresMax.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<MslPresMax> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? MslPresMax() : instance as! MslPresMax
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "MslPresMax", actual: "\(source)"))
            }
        }
        // Decoder for [MslPresMin]
        Decoders.addDecoder(clazz: [MslPresMin].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[MslPresMin]> in
            return Decoders.decode(clazz: [MslPresMin].self, source: source)
        }

        // Decoder for MslPresMin
        Decoders.addDecoder(clazz: MslPresMin.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<MslPresMin> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? MslPresMin() : instance as! MslPresMin
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "MslPresMin", actual: "\(source)"))
            }
        }
        // Decoder for [OnpointId]
        Decoders.addDecoder(clazz: [OnpointId].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[OnpointId]> in
            return Decoders.decode(clazz: [OnpointId].self, source: source)
        }

        // Decoder for OnpointId
        Decoders.addDecoder(clazz: OnpointId.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<OnpointId> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? OnpointId() : instance as! OnpointId
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "OnpointId", actual: "\(source)"))
            }
        }
        // Decoder for [OnpointObj]
        Decoders.addDecoder(clazz: [OnpointObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[OnpointObj]> in
            return Decoders.decode(clazz: [OnpointObj].self, source: source)
        }

        // Decoder for OnpointObj
        Decoders.addDecoder(clazz: OnpointObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<OnpointObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? OnpointObj() : instance as! OnpointObj
                switch Decoders.decodeOptional(clazz: OnpointId.self, source: sourceDictionary["onpointId"] as AnyObject?) {
                case let .success(value): _result.onpointId = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Latitude.self, source: sourceDictionary["latitude"] as AnyObject?) {
                case let .success(value): _result.latitude = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Longitude.self, source: sourceDictionary["longitude"] as AnyObject?) {
                case let .success(value): _result.longitude = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Timezone.self, source: sourceDictionary["timezone"] as AnyObject?) {
                case let .success(value): _result.timezone = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: CountryCode.self, source: sourceDictionary["countryCode"] as AnyObject?) {
                case let .success(value): _result.countryCode = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: CountryName.self, source: sourceDictionary["countryName"] as AnyObject?) {
                case let .success(value): _result.countryName = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: SubdivCode.self, source: sourceDictionary["subdivCode"] as AnyObject?) {
                case let .success(value): _result.subdivCode = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: SubdivName.self, source: sourceDictionary["subdivName"] as AnyObject?) {
                case let .success(value): _result.subdivName = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Grid.self, source: sourceDictionary["grid"] as AnyObject?) {
                case let .success(value): _result.grid = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "OnpointObj", actual: "\(source)"))
            }
        }
        // Decoder for [PointObj]
        Decoders.addDecoder(clazz: [PointObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[PointObj]> in
            return Decoders.decode(clazz: [PointObj].self, source: source)
        }

        // Decoder for PointObj
        Decoders.addDecoder(clazz: PointObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<PointObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? PointObj() : instance as! PointObj
                switch Decoders.decodeOptional(clazz: Latitude.self, source: sourceDictionary["latitude"] as AnyObject?) {
                case let .success(value): _result.latitude = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Longitude.self, source: sourceDictionary["longitude"] as AnyObject?) {
                case let .success(value): _result.longitude = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Timezone.self, source: sourceDictionary["timezone"] as AnyObject?) {
                case let .success(value): _result.timezone = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: CountryCode.self, source: sourceDictionary["countryCode"] as AnyObject?) {
                case let .success(value): _result.countryCode = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: CountryName.self, source: sourceDictionary["countryName"] as AnyObject?) {
                case let .success(value): _result.countryName = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: SubdivCode.self, source: sourceDictionary["subdivCode"] as AnyObject?) {
                case let .success(value): _result.subdivCode = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: SubdivName.self, source: sourceDictionary["subdivName"] as AnyObject?) {
                case let .success(value): _result.subdivName = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: BoundingPoints.self, source: sourceDictionary["boundingPoints"] as AnyObject?) {
                case let .success(value): _result.boundingPoints = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Grid.self, source: sourceDictionary["grid"] as AnyObject?) {
                case let .success(value): _result.grid = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "PointObj", actual: "\(source)"))
            }
        }
        // Decoder for [Population]
        Decoders.addDecoder(clazz: [Population].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[Population]> in
            return Decoders.decode(clazz: [Population].self, source: source)
        }

        // Decoder for Population
        Decoders.addDecoder(clazz: Population.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<Population> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? Population() : instance as! Population
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "Population", actual: "\(source)"))
            }
        }
        // Decoder for [Postcode]
        Decoders.addDecoder(clazz: [Postcode].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[Postcode]> in
            return Decoders.decode(clazz: [Postcode].self, source: source)
        }

        // Decoder for Postcode
        Decoders.addDecoder(clazz: Postcode.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<Postcode> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? Postcode() : instance as! Postcode
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "Postcode", actual: "\(source)"))
            }
        }
        // Decoder for [PostcodeObj]
        Decoders.addDecoder(clazz: [PostcodeObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[PostcodeObj]> in
            return Decoders.decode(clazz: [PostcodeObj].self, source: source)
        }

        // Decoder for PostcodeObj
        Decoders.addDecoder(clazz: PostcodeObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<PostcodeObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? PostcodeObj() : instance as! PostcodeObj
                switch Decoders.decodeOptional(clazz: Postcode.self, source: sourceDictionary["postcode"] as AnyObject?) {
                case let .success(value): _result.postcode = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Latitude.self, source: sourceDictionary["latitude"] as AnyObject?) {
                case let .success(value): _result.latitude = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Longitude.self, source: sourceDictionary["longitude"] as AnyObject?) {
                case let .success(value): _result.longitude = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Timezone.self, source: sourceDictionary["timezone"] as AnyObject?) {
                case let .success(value): _result.timezone = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: CountryCode.self, source: sourceDictionary["countryCode"] as AnyObject?) {
                case let .success(value): _result.countryCode = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: CountryName.self, source: sourceDictionary["countryName"] as AnyObject?) {
                case let .success(value): _result.countryName = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: SubdivCode.self, source: sourceDictionary["subdivCode"] as AnyObject?) {
                case let .success(value): _result.subdivCode = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: SubdivName.self, source: sourceDictionary["subdivName"] as AnyObject?) {
                case let .success(value): _result.subdivName = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: BoundingPoints.self, source: sourceDictionary["boundingPoints"] as AnyObject?) {
                case let .success(value): _result.boundingPoints = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Grid.self, source: sourceDictionary["grid"] as AnyObject?) {
                case let .success(value): _result.grid = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "PostcodeObj", actual: "\(source)"))
            }
        }
        // Decoder for [Precip]
        Decoders.addDecoder(clazz: [Precip].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[Precip]> in
            return Decoders.decode(clazz: [Precip].self, source: source)
        }

        // Decoder for Precip
        Decoders.addDecoder(clazz: Precip.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<Precip> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? Precip() : instance as! Precip
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "Precip", actual: "\(source)"))
            }
        }
        // Decoder for [PrecipProb]
        Decoders.addDecoder(clazz: [PrecipProb].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[PrecipProb]> in
            return Decoders.decode(clazz: [PrecipProb].self, source: source)
        }

        // Decoder for PrecipProb
        Decoders.addDecoder(clazz: PrecipProb.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<PrecipProb> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? PrecipProb() : instance as! PrecipProb
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "PrecipProb", actual: "\(source)"))
            }
        }
        // Decoder for [RadSolar]
        Decoders.addDecoder(clazz: [RadSolar].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[RadSolar]> in
            return Decoders.decode(clazz: [RadSolar].self, source: source)
        }

        // Decoder for RadSolar
        Decoders.addDecoder(clazz: RadSolar.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<RadSolar> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? RadSolar() : instance as! RadSolar
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "RadSolar", actual: "\(source)"))
            }
        }
        // Decoder for [RadSolarAvg]
        Decoders.addDecoder(clazz: [RadSolarAvg].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[RadSolarAvg]> in
            return Decoders.decode(clazz: [RadSolarAvg].self, source: source)
        }

        // Decoder for RadSolarAvg
        Decoders.addDecoder(clazz: RadSolarAvg.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<RadSolarAvg> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? RadSolarAvg() : instance as! RadSolarAvg
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "RadSolarAvg", actual: "\(source)"))
            }
        }
        // Decoder for [RadSolarMax]
        Decoders.addDecoder(clazz: [RadSolarMax].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[RadSolarMax]> in
            return Decoders.decode(clazz: [RadSolarMax].self, source: source)
        }

        // Decoder for RadSolarMax
        Decoders.addDecoder(clazz: RadSolarMax.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<RadSolarMax> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? RadSolarMax() : instance as! RadSolarMax
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "RadSolarMax", actual: "\(source)"))
            }
        }
        // Decoder for [RadSolarMin]
        Decoders.addDecoder(clazz: [RadSolarMin].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[RadSolarMin]> in
            return Decoders.decode(clazz: [RadSolarMin].self, source: source)
        }

        // Decoder for RadSolarMin
        Decoders.addDecoder(clazz: RadSolarMin.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<RadSolarMin> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? RadSolarMin() : instance as! RadSolarMin
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "RadSolarMin", actual: "\(source)"))
            }
        }
        // Decoder for [RadSolarTot]
        Decoders.addDecoder(clazz: [RadSolarTot].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[RadSolarTot]> in
            return Decoders.decode(clazz: [RadSolarTot].self, source: source)
        }

        // Decoder for RadSolarTot
        Decoders.addDecoder(clazz: RadSolarTot.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<RadSolarTot> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? RadSolarTot() : instance as! RadSolarTot
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "RadSolarTot", actual: "\(source)"))
            }
        }
        // Decoder for [RelHum]
        Decoders.addDecoder(clazz: [RelHum].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[RelHum]> in
            return Decoders.decode(clazz: [RelHum].self, source: source)
        }

        // Decoder for RelHum
        Decoders.addDecoder(clazz: RelHum.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<RelHum> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? RelHum() : instance as! RelHum
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "RelHum", actual: "\(source)"))
            }
        }
        // Decoder for [RelHumAvg]
        Decoders.addDecoder(clazz: [RelHumAvg].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[RelHumAvg]> in
            return Decoders.decode(clazz: [RelHumAvg].self, source: source)
        }

        // Decoder for RelHumAvg
        Decoders.addDecoder(clazz: RelHumAvg.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<RelHumAvg> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? RelHumAvg() : instance as! RelHumAvg
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "RelHumAvg", actual: "\(source)"))
            }
        }
        // Decoder for [RelHumMax]
        Decoders.addDecoder(clazz: [RelHumMax].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[RelHumMax]> in
            return Decoders.decode(clazz: [RelHumMax].self, source: source)
        }

        // Decoder for RelHumMax
        Decoders.addDecoder(clazz: RelHumMax.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<RelHumMax> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? RelHumMax() : instance as! RelHumMax
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "RelHumMax", actual: "\(source)"))
            }
        }
        // Decoder for [RelHumMin]
        Decoders.addDecoder(clazz: [RelHumMin].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[RelHumMin]> in
            return Decoders.decode(clazz: [RelHumMin].self, source: source)
        }

        // Decoder for RelHumMin
        Decoders.addDecoder(clazz: RelHumMin.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<RelHumMin> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? RelHumMin() : instance as! RelHumMin
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "RelHumMin", actual: "\(source)"))
            }
        }
        // Decoder for [SamplePointsInner]
        Decoders.addDecoder(clazz: [SamplePointsInner].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[SamplePointsInner]> in
            return Decoders.decode(clazz: [SamplePointsInner].self, source: source)
        }

        // Decoder for SamplePointsInner
        Decoders.addDecoder(clazz: SamplePointsInner.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<SamplePointsInner> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? SamplePointsInner() : instance as! SamplePointsInner
                switch Decoders.decodeOptional(clazz: OnpointId.self, source: sourceDictionary["onpointId"] as AnyObject?) {
                case let .success(value): _result.onpointId = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Latitude.self, source: sourceDictionary["latitude"] as AnyObject?) {
                case let .success(value): _result.latitude = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Longitude.self, source: sourceDictionary["longitude"] as AnyObject?) {
                case let .success(value): _result.longitude = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: Grid.self, source: sourceDictionary["grid"] as AnyObject?) {
                case let .success(value): _result.grid = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: DistancePop.self, source: sourceDictionary["distance"] as AnyObject?) {
                case let .success(value): _result.distance = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "SamplePointsInner", actual: "\(source)"))
            }
        }
        // Decoder for [SfcPres]
        Decoders.addDecoder(clazz: [SfcPres].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[SfcPres]> in
            return Decoders.decode(clazz: [SfcPres].self, source: source)
        }

        // Decoder for SfcPres
        Decoders.addDecoder(clazz: SfcPres.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<SfcPres> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? SfcPres() : instance as! SfcPres
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "SfcPres", actual: "\(source)"))
            }
        }
        // Decoder for [SfcPresAvg]
        Decoders.addDecoder(clazz: [SfcPresAvg].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[SfcPresAvg]> in
            return Decoders.decode(clazz: [SfcPresAvg].self, source: source)
        }

        // Decoder for SfcPresAvg
        Decoders.addDecoder(clazz: SfcPresAvg.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<SfcPresAvg> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? SfcPresAvg() : instance as! SfcPresAvg
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "SfcPresAvg", actual: "\(source)"))
            }
        }
        // Decoder for [SfcPresMax]
        Decoders.addDecoder(clazz: [SfcPresMax].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[SfcPresMax]> in
            return Decoders.decode(clazz: [SfcPresMax].self, source: source)
        }

        // Decoder for SfcPresMax
        Decoders.addDecoder(clazz: SfcPresMax.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<SfcPresMax> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? SfcPresMax() : instance as! SfcPresMax
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "SfcPresMax", actual: "\(source)"))
            }
        }
        // Decoder for [SfcPresMin]
        Decoders.addDecoder(clazz: [SfcPresMin].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[SfcPresMin]> in
            return Decoders.decode(clazz: [SfcPresMin].self, source: source)
        }

        // Decoder for SfcPresMin
        Decoders.addDecoder(clazz: SfcPresMin.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<SfcPresMin> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? SfcPresMin() : instance as! SfcPresMin
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "SfcPresMin", actual: "\(source)"))
            }
        }
        // Decoder for [Snowfall]
        Decoders.addDecoder(clazz: [Snowfall].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[Snowfall]> in
            return Decoders.decode(clazz: [Snowfall].self, source: source)
        }

        // Decoder for Snowfall
        Decoders.addDecoder(clazz: Snowfall.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<Snowfall> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? Snowfall() : instance as! Snowfall
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "Snowfall", actual: "\(source)"))
            }
        }
        // Decoder for [SnowfallProb]
        Decoders.addDecoder(clazz: [SnowfallProb].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[SnowfallProb]> in
            return Decoders.decode(clazz: [SnowfallProb].self, source: source)
        }

        // Decoder for SnowfallProb
        Decoders.addDecoder(clazz: SnowfallProb.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<SnowfallProb> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? SnowfallProb() : instance as! SnowfallProb
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "SnowfallProb", actual: "\(source)"))
            }
        }
        // Decoder for [SpcHum]
        Decoders.addDecoder(clazz: [SpcHum].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[SpcHum]> in
            return Decoders.decode(clazz: [SpcHum].self, source: source)
        }

        // Decoder for SpcHum
        Decoders.addDecoder(clazz: SpcHum.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<SpcHum> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? SpcHum() : instance as! SpcHum
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "SpcHum", actual: "\(source)"))
            }
        }
        // Decoder for [SpcHumAvg]
        Decoders.addDecoder(clazz: [SpcHumAvg].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[SpcHumAvg]> in
            return Decoders.decode(clazz: [SpcHumAvg].self, source: source)
        }

        // Decoder for SpcHumAvg
        Decoders.addDecoder(clazz: SpcHumAvg.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<SpcHumAvg> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? SpcHumAvg() : instance as! SpcHumAvg
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "SpcHumAvg", actual: "\(source)"))
            }
        }
        // Decoder for [SpcHumMax]
        Decoders.addDecoder(clazz: [SpcHumMax].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[SpcHumMax]> in
            return Decoders.decode(clazz: [SpcHumMax].self, source: source)
        }

        // Decoder for SpcHumMax
        Decoders.addDecoder(clazz: SpcHumMax.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<SpcHumMax> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? SpcHumMax() : instance as! SpcHumMax
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "SpcHumMax", actual: "\(source)"))
            }
        }
        // Decoder for [SpcHumMin]
        Decoders.addDecoder(clazz: [SpcHumMin].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[SpcHumMin]> in
            return Decoders.decode(clazz: [SpcHumMin].self, source: source)
        }

        // Decoder for SpcHumMin
        Decoders.addDecoder(clazz: SpcHumMin.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<SpcHumMin> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? SpcHumMin() : instance as! SpcHumMin
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "SpcHumMin", actual: "\(source)"))
            }
        }
        // Decoder for [SubdivCode]
        Decoders.addDecoder(clazz: [SubdivCode].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[SubdivCode]> in
            return Decoders.decode(clazz: [SubdivCode].self, source: source)
        }

        // Decoder for SubdivCode
        Decoders.addDecoder(clazz: SubdivCode.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<SubdivCode> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? SubdivCode() : instance as! SubdivCode
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "SubdivCode", actual: "\(source)"))
            }
        }
        // Decoder for [SubdivName]
        Decoders.addDecoder(clazz: [SubdivName].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[SubdivName]> in
            return Decoders.decode(clazz: [SubdivName].self, source: source)
        }

        // Decoder for SubdivName
        Decoders.addDecoder(clazz: SubdivName.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<SubdivName> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? SubdivName() : instance as! SubdivName
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "SubdivName", actual: "\(source)"))
            }
        }
        // Decoder for [Temp]
        Decoders.addDecoder(clazz: [Temp].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[Temp]> in
            return Decoders.decode(clazz: [Temp].self, source: source)
        }

        // Decoder for Temp
        Decoders.addDecoder(clazz: Temp.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<Temp> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? Temp() : instance as! Temp
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "Temp", actual: "\(source)"))
            }
        }
        // Decoder for [TempAvg]
        Decoders.addDecoder(clazz: [TempAvg].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[TempAvg]> in
            return Decoders.decode(clazz: [TempAvg].self, source: source)
        }

        // Decoder for TempAvg
        Decoders.addDecoder(clazz: TempAvg.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<TempAvg> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? TempAvg() : instance as! TempAvg
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "TempAvg", actual: "\(source)"))
            }
        }
        // Decoder for [TempMax]
        Decoders.addDecoder(clazz: [TempMax].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[TempMax]> in
            return Decoders.decode(clazz: [TempMax].self, source: source)
        }

        // Decoder for TempMax
        Decoders.addDecoder(clazz: TempMax.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<TempMax> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? TempMax() : instance as! TempMax
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "TempMax", actual: "\(source)"))
            }
        }
        // Decoder for [TempMin]
        Decoders.addDecoder(clazz: [TempMin].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[TempMin]> in
            return Decoders.decode(clazz: [TempMin].self, source: source)
        }

        // Decoder for TempMin
        Decoders.addDecoder(clazz: TempMin.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<TempMin> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? TempMin() : instance as! TempMin
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "TempMin", actual: "\(source)"))
            }
        }
        // Decoder for [Timestamp]
        Decoders.addDecoder(clazz: [Timestamp].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[Timestamp]> in
            return Decoders.decode(clazz: [Timestamp].self, source: source)
        }

        // Decoder for Timestamp
        Decoders.addDecoder(clazz: Timestamp.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<Timestamp> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? Timestamp() : instance as! Timestamp
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "Timestamp", actual: "\(source)"))
            }
        }
        // Decoder for [TimestampEnd]
        Decoders.addDecoder(clazz: [TimestampEnd].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[TimestampEnd]> in
            return Decoders.decode(clazz: [TimestampEnd].self, source: source)
        }

        // Decoder for TimestampEnd
        Decoders.addDecoder(clazz: TimestampEnd.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<TimestampEnd> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? TimestampEnd() : instance as! TimestampEnd
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "TimestampEnd", actual: "\(source)"))
            }
        }
        // Decoder for [TimestampInit]
        Decoders.addDecoder(clazz: [TimestampInit].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[TimestampInit]> in
            return Decoders.decode(clazz: [TimestampInit].self, source: source)
        }

        // Decoder for TimestampInit
        Decoders.addDecoder(clazz: TimestampInit.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<TimestampInit> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? TimestampInit() : instance as! TimestampInit
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "TimestampInit", actual: "\(source)"))
            }
        }
        // Decoder for [TimestampRangeObj]
        Decoders.addDecoder(clazz: [TimestampRangeObj].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[TimestampRangeObj]> in
            return Decoders.decode(clazz: [TimestampRangeObj].self, source: source)
        }

        // Decoder for TimestampRangeObj
        Decoders.addDecoder(clazz: TimestampRangeObj.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<TimestampRangeObj> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? TimestampRangeObj() : instance as! TimestampRangeObj
                switch Decoders.decodeOptional(clazz: TimestampStart.self, source: sourceDictionary["timestampStart"] as AnyObject?) {
                case let .success(value): _result.timestampStart = value
                case let .failure(error): break
                }
                switch Decoders.decodeOptional(clazz: TimestampEnd.self, source: sourceDictionary["timestampEnd"] as AnyObject?) {
                case let .success(value): _result.timestampEnd = value
                case let .failure(error): break
                }
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "TimestampRangeObj", actual: "\(source)"))
            }
        }
        // Decoder for [TimestampStart]
        Decoders.addDecoder(clazz: [TimestampStart].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[TimestampStart]> in
            return Decoders.decode(clazz: [TimestampStart].self, source: source)
        }

        // Decoder for TimestampStart
        Decoders.addDecoder(clazz: TimestampStart.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<TimestampStart> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? TimestampStart() : instance as! TimestampStart
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "TimestampStart", actual: "\(source)"))
            }
        }
        // Decoder for [Timezone]
        Decoders.addDecoder(clazz: [Timezone].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[Timezone]> in
            return Decoders.decode(clazz: [Timezone].self, source: source)
        }

        // Decoder for Timezone
        Decoders.addDecoder(clazz: Timezone.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<Timezone> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? Timezone() : instance as! Timezone
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "Timezone", actual: "\(source)"))
            }
        }
        // Decoder for [WetBulb]
        Decoders.addDecoder(clazz: [WetBulb].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WetBulb]> in
            return Decoders.decode(clazz: [WetBulb].self, source: source)
        }

        // Decoder for WetBulb
        Decoders.addDecoder(clazz: WetBulb.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WetBulb> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WetBulb() : instance as! WetBulb
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WetBulb", actual: "\(source)"))
            }
        }
        // Decoder for [WetBulbAvg]
        Decoders.addDecoder(clazz: [WetBulbAvg].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WetBulbAvg]> in
            return Decoders.decode(clazz: [WetBulbAvg].self, source: source)
        }

        // Decoder for WetBulbAvg
        Decoders.addDecoder(clazz: WetBulbAvg.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WetBulbAvg> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WetBulbAvg() : instance as! WetBulbAvg
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WetBulbAvg", actual: "\(source)"))
            }
        }
        // Decoder for [WetBulbMax]
        Decoders.addDecoder(clazz: [WetBulbMax].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WetBulbMax]> in
            return Decoders.decode(clazz: [WetBulbMax].self, source: source)
        }

        // Decoder for WetBulbMax
        Decoders.addDecoder(clazz: WetBulbMax.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WetBulbMax> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WetBulbMax() : instance as! WetBulbMax
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WetBulbMax", actual: "\(source)"))
            }
        }
        // Decoder for [WetBulbMin]
        Decoders.addDecoder(clazz: [WetBulbMin].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WetBulbMin]> in
            return Decoders.decode(clazz: [WetBulbMin].self, source: source)
        }

        // Decoder for WetBulbMin
        Decoders.addDecoder(clazz: WetBulbMin.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WetBulbMin> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WetBulbMin() : instance as! WetBulbMin
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WetBulbMin", actual: "\(source)"))
            }
        }
        // Decoder for [WindChill]
        Decoders.addDecoder(clazz: [WindChill].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindChill]> in
            return Decoders.decode(clazz: [WindChill].self, source: source)
        }

        // Decoder for WindChill
        Decoders.addDecoder(clazz: WindChill.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindChill> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindChill() : instance as! WindChill
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindChill", actual: "\(source)"))
            }
        }
        // Decoder for [WindChillAvg]
        Decoders.addDecoder(clazz: [WindChillAvg].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindChillAvg]> in
            return Decoders.decode(clazz: [WindChillAvg].self, source: source)
        }

        // Decoder for WindChillAvg
        Decoders.addDecoder(clazz: WindChillAvg.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindChillAvg> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindChillAvg() : instance as! WindChillAvg
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindChillAvg", actual: "\(source)"))
            }
        }
        // Decoder for [WindChillMax]
        Decoders.addDecoder(clazz: [WindChillMax].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindChillMax]> in
            return Decoders.decode(clazz: [WindChillMax].self, source: source)
        }

        // Decoder for WindChillMax
        Decoders.addDecoder(clazz: WindChillMax.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindChillMax> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindChillMax() : instance as! WindChillMax
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindChillMax", actual: "\(source)"))
            }
        }
        // Decoder for [WindChillMin]
        Decoders.addDecoder(clazz: [WindChillMin].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindChillMin]> in
            return Decoders.decode(clazz: [WindChillMin].self, source: source)
        }

        // Decoder for WindChillMin
        Decoders.addDecoder(clazz: WindChillMin.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindChillMin> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindChillMin() : instance as! WindChillMin
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindChillMin", actual: "\(source)"))
            }
        }
        // Decoder for [WindDir]
        Decoders.addDecoder(clazz: [WindDir].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindDir]> in
            return Decoders.decode(clazz: [WindDir].self, source: source)
        }

        // Decoder for WindDir
        Decoders.addDecoder(clazz: WindDir.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindDir> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindDir() : instance as! WindDir
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindDir", actual: "\(source)"))
            }
        }
        // Decoder for [WindDir100m]
        Decoders.addDecoder(clazz: [WindDir100m].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindDir100m]> in
            return Decoders.decode(clazz: [WindDir100m].self, source: source)
        }

        // Decoder for WindDir100m
        Decoders.addDecoder(clazz: WindDir100m.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindDir100m> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindDir100m() : instance as! WindDir100m
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindDir100m", actual: "\(source)"))
            }
        }
        // Decoder for [WindDir100mAvg]
        Decoders.addDecoder(clazz: [WindDir100mAvg].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindDir100mAvg]> in
            return Decoders.decode(clazz: [WindDir100mAvg].self, source: source)
        }

        // Decoder for WindDir100mAvg
        Decoders.addDecoder(clazz: WindDir100mAvg.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindDir100mAvg> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindDir100mAvg() : instance as! WindDir100mAvg
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindDir100mAvg", actual: "\(source)"))
            }
        }
        // Decoder for [WindDir80m]
        Decoders.addDecoder(clazz: [WindDir80m].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindDir80m]> in
            return Decoders.decode(clazz: [WindDir80m].self, source: source)
        }

        // Decoder for WindDir80m
        Decoders.addDecoder(clazz: WindDir80m.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindDir80m> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindDir80m() : instance as! WindDir80m
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindDir80m", actual: "\(source)"))
            }
        }
        // Decoder for [WindDir80mAvg]
        Decoders.addDecoder(clazz: [WindDir80mAvg].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindDir80mAvg]> in
            return Decoders.decode(clazz: [WindDir80mAvg].self, source: source)
        }

        // Decoder for WindDir80mAvg
        Decoders.addDecoder(clazz: WindDir80mAvg.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindDir80mAvg> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindDir80mAvg() : instance as! WindDir80mAvg
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindDir80mAvg", actual: "\(source)"))
            }
        }
        // Decoder for [WindDirAvg]
        Decoders.addDecoder(clazz: [WindDirAvg].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindDirAvg]> in
            return Decoders.decode(clazz: [WindDirAvg].self, source: source)
        }

        // Decoder for WindDirAvg
        Decoders.addDecoder(clazz: WindDirAvg.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindDirAvg> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindDirAvg() : instance as! WindDirAvg
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindDirAvg", actual: "\(source)"))
            }
        }
        // Decoder for [WindSpd]
        Decoders.addDecoder(clazz: [WindSpd].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindSpd]> in
            return Decoders.decode(clazz: [WindSpd].self, source: source)
        }

        // Decoder for WindSpd
        Decoders.addDecoder(clazz: WindSpd.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindSpd> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindSpd() : instance as! WindSpd
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindSpd", actual: "\(source)"))
            }
        }
        // Decoder for [WindSpd100m]
        Decoders.addDecoder(clazz: [WindSpd100m].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindSpd100m]> in
            return Decoders.decode(clazz: [WindSpd100m].self, source: source)
        }

        // Decoder for WindSpd100m
        Decoders.addDecoder(clazz: WindSpd100m.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindSpd100m> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindSpd100m() : instance as! WindSpd100m
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindSpd100m", actual: "\(source)"))
            }
        }
        // Decoder for [WindSpd100mAvg]
        Decoders.addDecoder(clazz: [WindSpd100mAvg].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindSpd100mAvg]> in
            return Decoders.decode(clazz: [WindSpd100mAvg].self, source: source)
        }

        // Decoder for WindSpd100mAvg
        Decoders.addDecoder(clazz: WindSpd100mAvg.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindSpd100mAvg> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindSpd100mAvg() : instance as! WindSpd100mAvg
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindSpd100mAvg", actual: "\(source)"))
            }
        }
        // Decoder for [WindSpd100mMax]
        Decoders.addDecoder(clazz: [WindSpd100mMax].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindSpd100mMax]> in
            return Decoders.decode(clazz: [WindSpd100mMax].self, source: source)
        }

        // Decoder for WindSpd100mMax
        Decoders.addDecoder(clazz: WindSpd100mMax.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindSpd100mMax> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindSpd100mMax() : instance as! WindSpd100mMax
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindSpd100mMax", actual: "\(source)"))
            }
        }
        // Decoder for [WindSpd100mMin]
        Decoders.addDecoder(clazz: [WindSpd100mMin].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindSpd100mMin]> in
            return Decoders.decode(clazz: [WindSpd100mMin].self, source: source)
        }

        // Decoder for WindSpd100mMin
        Decoders.addDecoder(clazz: WindSpd100mMin.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindSpd100mMin> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindSpd100mMin() : instance as! WindSpd100mMin
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindSpd100mMin", actual: "\(source)"))
            }
        }
        // Decoder for [WindSpd80m]
        Decoders.addDecoder(clazz: [WindSpd80m].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindSpd80m]> in
            return Decoders.decode(clazz: [WindSpd80m].self, source: source)
        }

        // Decoder for WindSpd80m
        Decoders.addDecoder(clazz: WindSpd80m.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindSpd80m> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindSpd80m() : instance as! WindSpd80m
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindSpd80m", actual: "\(source)"))
            }
        }
        // Decoder for [WindSpd80mAvg]
        Decoders.addDecoder(clazz: [WindSpd80mAvg].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindSpd80mAvg]> in
            return Decoders.decode(clazz: [WindSpd80mAvg].self, source: source)
        }

        // Decoder for WindSpd80mAvg
        Decoders.addDecoder(clazz: WindSpd80mAvg.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindSpd80mAvg> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindSpd80mAvg() : instance as! WindSpd80mAvg
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindSpd80mAvg", actual: "\(source)"))
            }
        }
        // Decoder for [WindSpd80mMax]
        Decoders.addDecoder(clazz: [WindSpd80mMax].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindSpd80mMax]> in
            return Decoders.decode(clazz: [WindSpd80mMax].self, source: source)
        }

        // Decoder for WindSpd80mMax
        Decoders.addDecoder(clazz: WindSpd80mMax.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindSpd80mMax> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindSpd80mMax() : instance as! WindSpd80mMax
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindSpd80mMax", actual: "\(source)"))
            }
        }
        // Decoder for [WindSpd80mMin]
        Decoders.addDecoder(clazz: [WindSpd80mMin].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindSpd80mMin]> in
            return Decoders.decode(clazz: [WindSpd80mMin].self, source: source)
        }

        // Decoder for WindSpd80mMin
        Decoders.addDecoder(clazz: WindSpd80mMin.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindSpd80mMin> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindSpd80mMin() : instance as! WindSpd80mMin
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindSpd80mMin", actual: "\(source)"))
            }
        }
        // Decoder for [WindSpdAvg]
        Decoders.addDecoder(clazz: [WindSpdAvg].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindSpdAvg]> in
            return Decoders.decode(clazz: [WindSpdAvg].self, source: source)
        }

        // Decoder for WindSpdAvg
        Decoders.addDecoder(clazz: WindSpdAvg.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindSpdAvg> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindSpdAvg() : instance as! WindSpdAvg
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindSpdAvg", actual: "\(source)"))
            }
        }
        // Decoder for [WindSpdMax]
        Decoders.addDecoder(clazz: [WindSpdMax].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindSpdMax]> in
            return Decoders.decode(clazz: [WindSpdMax].self, source: source)
        }

        // Decoder for WindSpdMax
        Decoders.addDecoder(clazz: WindSpdMax.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindSpdMax> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindSpdMax() : instance as! WindSpdMax
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindSpdMax", actual: "\(source)"))
            }
        }
        // Decoder for [WindSpdMin]
        Decoders.addDecoder(clazz: [WindSpdMin].self) { (source: AnyObject, instance: AnyObject?) -> Decoded<[WindSpdMin]> in
            return Decoders.decode(clazz: [WindSpdMin].self, source: source)
        }

        // Decoder for WindSpdMin
        Decoders.addDecoder(clazz: WindSpdMin.self) { (source: AnyObject, instance: AnyObject?) -> Decoded<WindSpdMin> in
            if let sourceDictionary = source as? [AnyHashable: Any] {
                let _result = instance == nil ? WindSpdMin() : instance as! WindSpdMin
                return .success(_result)
            } else {
                return .failure(.typeMismatch(expected: "WindSpdMin", actual: "\(source)"))
            }
        }
    }()

    static fileprivate func initialize() {
        _ = Decoders.__once
    }
}
